package it.dsestili.jhash.core;

/*
JHash a simple hash code generator
Copyright (C) 2013 Davide Sestili

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

import java.awt.Frame;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.text.DecimalFormat;
import java.util.Vector;
import javax.swing.JFileChooser;

public class Utils 
{
	private static final int GB = 1073741824;
	private static final int MB = 1048576;
	private static final int KB = 1024;
	
	public static String getFriendlySize(final long size)
	{
		String friendlySize;
		DecimalFormat myFormatter = new DecimalFormat("###.##");
		
		if(size >= GB)
		{
			final double gb = (double)size / (double)GB;
			friendlySize = myFormatter.format(gb) + " GB";
		}
		else if(size >= MB)
		{
			final double mb = (double)size / (double)MB;
			friendlySize = myFormatter.format(mb) + " MB";
		}
		else if(size >= KB)
		{
			final double kb = (double)size / (double)KB;
			friendlySize = myFormatter.format(kb) + " KB";
		}
		else
		{
			friendlySize = size + " B";
		}
		
		return friendlySize;
	}
	
	public static void saveHashToFile(Frame frame, Vector<Vector<String>> hashList) throws Throwable
	{
		JFileChooser chooser = new JFileChooser();
		chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
		
		if(chooser.showSaveDialog(frame) != JFileChooser.APPROVE_OPTION)
		{
			return;
		}
		
		File file = chooser.getSelectedFile();
		
		FileOutputStream fos = new FileOutputStream(file);
		BufferedOutputStream bos = new BufferedOutputStream(fos);
		
		for(Vector<String> info : hashList)
		{
			String line = info.get(1) + " " + info.get(0) + "\n";
			byte[] data = line.getBytes();
			bos.write(data, 0, data.length);
		}
		
		bos.close();
		fos.close();
	}
}
